#!/bin/bash

# This file initialize a brand new LXC vm
# file to be used with AlternC

target="/var/lib/alternc-lxc/vm_disk.img"

if [[ -e "$target" ]] ; then
  echo "$target allready exist"
  exit 1
fi

echo 'Enter "yes" to init your VM file to use with'
echo 'Alternc LXC'
read rep

if [ ! "$rep" == "yes" ] ; then
  echo "OK, nevermind. See you later!"
  exit 0
fi

echo 'OK, initializing in progress'

mkdir -p "$(dirname "$target")"

# Create the target file
dd if=/dev/zero of="$target" bs=1M count=800 || exit 2
mkfs.ext3 -F "$target" || exit 2

# Mount the target file
dir="$(mktemp -d /tmp/alternc-lxc.XXX)"
mount -o loop,rw -t ext3 "$target" "$dir" || exit 2
mkdir -p "$dir/var/cache/apt/archives"
mount -t tmpfs tmpfs "$dir/var/cache/apt/archives"
mkdir "$dir/var/cache/apt/archives/partial"

# Setup the target file
echo Install and launch debootstrap
apt-get install debootstrap
if [ "$MIRROR" ]
then
    debootstrap wheezy "$dir" "$MIRROR" || exit 2
else
    debootstrap wheezy "$dir" || exit 2
fi
chroot "$dir" apt-get clean

echo Some tuning
# Set up the console
sed -i -e 's/tty1/console/' "$dir/etc/inittab" || exit 2
sed -i -e 's/tty2/tty1/'    "$dir/etc/inittab" || exit 2

# Create da console
chroot "$dir" mknod -m 666 /dev/tty1 c 4 1
chroot "$dir" mknod -m 666 /dev/tty2 c 4 2
chroot "$dir" mknod -m 666 /dev/tty3 c 4 3
chroot "$dir" mknod -m 666 /dev/tty4 c 4 4
chroot "$dir" mknod -m 666 /dev/tty5 c 4 5
chroot "$dir" mknod -m 666 /dev/tty6 c 4 5

# Some necessary configuration
chroot "$dir" apt-get update
#echo "Root password" # no need to : its deleted at VM start-time
#chroot "$dir" passwd
chroot "$dir" apt-get install -y locales 
chroot "$dir" dpkg-reconfigure locales
chroot "$dir" apt-get install -y vim screen mysql-client rsync git subversion mercurial unzip elinks less vim-nox emacs23-nox joe nano ncftp telnet lftp openssh-server
chroot "$dir" apt-get clean

# If you want to add MORE packages, add them here: not above:
#chroot "$dir" apt-get install -y foo bar
#chroot "$dir" apt-get clean

# unrar is non-free, don't use it ;) 
chroot "$dir" mkdir -p "/var/virtual"

# Make the template files for group and shadow
sysdir="/etc/alternc-lxc/skels/"
mkdir -p "$sysdir"
for ii in group passwd shadow ; do
  cp "$dir/etc/$ii" "$sysdir/$ii.tmpl"
  mv "$dir/etc/$ii" "$dir/var/virtual/$ii"
  ln -s "/var/virtual/$ii" "$dir/etc/$ii"
done

# Tune what must be launched at boot
chroot "$dir" /usr/sbin/update-rc.d -f umountfs remove
chroot "$dir" /usr/sbin/update-rc.d -f hwclock.sh remove
chroot "$dir" /usr/sbin/update-rc.d -f hwclockfirst.sh remove
chroot "$dir" /usr/sbin/update-rc.d -f rsyslog remove

# prepare the ssh server to use persistent keys :
chroot "$dir" rm -f /etc/ssh/*key* 
chroot "$dir" ln -s /var/virtual/ssh_host_rsa_key /etc/ssh/ssh_host_rsa_key
chroot "$dir" ln -s /var/virtual/ssh_host_rsa_key.pub /etc/ssh/ssh_host_rsa_key.pub
chroot "$dir" ln -s /var/virtual/ssh_host_dsa_key /etc/ssh/ssh_host_dsa_key
chroot "$dir" ln -s /var/virtual/ssh_host_dsa_key.pub /etc/ssh/ssh_host_dsa_key.pub
chroot "$dir" ln -s /var/virtual/ssh_host_ecdsa_key /etc/ssh/ssh_host_ecdsa_key
chroot "$dir" ln -s /var/virtual/ssh_host_ecdsa_key.pub /etc/ssh/ssh_host_ecdsa_key.pub

# The end, umount all
echo Unmount working dir
umount "$dir/var/cache/apt/archives" || exit 2
umount "$dir" || exit 2

rmdir "$dir" || exit 2

