#!/bin/bash

# Copy the persistent files to the tmpfs directory
# and the auth file (passwd, shadow, group)
# And mount the home

# parameters :
# ./script start vmname vmdir server login pass uid persistentdir

action="$1"
vmname="$2"
vmdir="$3"
server="$4"
login="$5"
pass="$6"
uid="$7"
pdir="$8"

# Nothing to do if not a start
if [ "$action" != "start" ] ; then
  exit 0
fi

# Create the persistent 
test -d "$pdir" || mkdir -p "$pdir"

# Generate the ssh key
if [ ! -f "$pdir/ssh_host_rsa_key" -o ! -f "$pdir/ssh_host_dsa_key" -o ! -f "$pdir/ssh_host_ecdsa_key" ]
then
    rm -f "$pdir/ssh_host_rsa_key" "$pdir/ssh_host_dsa_key" "$pdir/ssh_host_ecdsa_key"
    ssh-keygen -N '' -q -f "$pdir/ssh_host_rsa_key" -t rsa
    ssh-keygen -N '' -q -f "$pdir/ssh_host_dsa_key" -t dsa
    ssh-keygen -N '' -q -f "$pdir/ssh_host_ecdsa_key" -t ecdsa
    (
      ssh-keygen -l -f "$pdir/ssh_host_rsa_key.pub" 
      ssh-keygen -l -f "$pdir/ssh_host_dsa_key.pub" 
      ssh-keygen -l -f "$pdir/ssh_host_ecdsa_key.pub" 
    ) > "$pdir/keys_fingerprint.txt"
fi

# Mount the tmpfs.
# Isn't done by LXC because it must be
# ready when it start
mount -o size=10M none -t tmpfs "$vmdir"/rootfs/var/virtual/
mount -o size=10M none -t tmpfs "$vmdir"/rootfs/home/

cp -ar "$pdir"/* "$vmdir"/rootfs/var/virtual/

# Set the files
for ii in group passwd shadow ; do
  cp /etc/alternc-lxc/skels/$ii.tmpl "$vmdir"/rootfs/var/virtual/$ii
done
# Disable the root password
sed -i -e 's/\(root:\)[^:]*\(:.*\)/\1!wontwork\2/' "$vmdir"/rootfs/var/virtual/shadow

# Add the user and set his homedir
mkdir "$vmdir"/rootfs/home/$login
chown $uid:$uid "$vmdir"/rootfs/home/$login
echo "$login:x:$uid:$uid:$login:/home/$login/lxc-home:/bin/bash" >> "$vmdir"/rootfs/var/virtual/"/passwd"
echo "$login:$pass:13884:0:99999:7:::" >> "$vmdir"/rootfs/var/virtual/"/shadow"
echo "$login:x:$uid:$login" >> "$vmdir"/rootfs/var/virtual/"/group"


